import { CfnRegistry } from '../../aws-glue';
import { IEventSourceMapping, IFunction } from '../../aws-lambda/lib';
import { ISchemaRegistry, KafkaSchemaRegistryConfig, SchemaRegistryProps } from '../../aws-lambda/lib/schema-registry';
/**
 * Properties for glue schema registry configuration.
 */
export interface GlueSchemaRegistryProps extends SchemaRegistryProps {
    /**
     * The CfnRegistry reference of your glue schema registry. If used, schemaRegistryArn will be ignored.
     *
     * @default - none
     */
    readonly schemaRegistry?: CfnRegistry;
    /**
     * The Arn of your glue schema registry.
     *
     * @default - none
     */
    readonly schemaRegistryArn?: string;
}
/**
 * Glue schema registry configuration for a Lambda event source.
 */
export declare class GlueSchemaRegistry implements ISchemaRegistry {
    private readonly props;
    constructor(props: GlueSchemaRegistryProps);
    /**
     * Returns a schema registry configuration.
     */
    bind(_target: IEventSourceMapping, targetHandler: IFunction): KafkaSchemaRegistryConfig;
    private getRegistryProps;
    private getSchemaRegistryPolicies;
}
