import * as cdk from "../../core";
import * as constructs from "constructs";
import * as cfn_parse from "../../core/lib/helpers-internal";
/**
 * The `AWS::ODB::CloudAutonomousVmCluster` resource creates an Autonomous VM cluster.
 *
 * An Autonomous VM cluster provides the infrastructure for running Autonomous Databases.
 *
 * @cloudformationResource AWS::ODB::CloudAutonomousVmCluster
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html
 */
export declare class CfnCloudAutonomousVmCluster extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggableV2 {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnCloudAutonomousVmCluster from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnCloudAutonomousVmCluster;
    /**
     * The percentage of data storage currently in use for Autonomous Databases in the Autonomous VM cluster.
     *
     * @cloudformationAttribute AutonomousDataStoragePercentage
     */
    readonly attrAutonomousDataStoragePercentage: cdk.IResolvable;
    /**
     * The available data storage space for Autonomous Databases in the Autonomous VM cluster, in TB.
     *
     * @cloudformationAttribute AvailableAutonomousDataStorageSizeInTBs
     */
    readonly attrAvailableAutonomousDataStorageSizeInTBs: cdk.IResolvable;
    /**
     * The number of Autonomous CDBs that you can create with the currently available storage.
     *
     * @cloudformationAttribute AvailableContainerDatabases
     */
    readonly attrAvailableContainerDatabases: number;
    /**
     * The number of CPU cores available for allocation to Autonomous Databases.
     *
     * @cloudformationAttribute AvailableCpus
     */
    readonly attrAvailableCpus: cdk.IResolvable;
    /**
     * The Amazon Resource Name (ARN) for the Autonomous VM cluster.
     *
     * @cloudformationAttribute CloudAutonomousVmClusterArn
     */
    readonly attrCloudAutonomousVmClusterArn: string;
    /**
     * The unique identifier of the Autonomous VM cluster.
     *
     * @cloudformationAttribute CloudAutonomousVmClusterId
     */
    readonly attrCloudAutonomousVmClusterId: string;
    /**
     * The compute model of the Autonomous VM cluster: ECPU or OCPU.
     *
     * @cloudformationAttribute ComputeModel
     */
    readonly attrComputeModel: string;
    /**
     * The total number of CPU cores in the Autonomous VM cluster.
     *
     * @cloudformationAttribute CpuCoreCount
     */
    readonly attrCpuCoreCount: number;
    /**
     * The percentage of total CPU cores currently in use in the Autonomous VM cluster.
     *
     * @cloudformationAttribute CpuPercentage
     */
    readonly attrCpuPercentage: cdk.IResolvable;
    /**
     * The total data storage allocated to the Autonomous VM cluster, in GB.
     *
     * @cloudformationAttribute DataStorageSizeInGBs
     */
    readonly attrDataStorageSizeInGBs: cdk.IResolvable;
    /**
     * The total data storage allocated to the Autonomous VM cluster, in TB.
     *
     * @cloudformationAttribute DataStorageSizeInTBs
     */
    readonly attrDataStorageSizeInTBs: cdk.IResolvable;
    /**
     * The local node storage allocated to the Autonomous VM cluster, in gigabytes (GB).
     *
     * @cloudformationAttribute DbNodeStorageSizeInGBs
     */
    readonly attrDbNodeStorageSizeInGBs: number;
    /**
     * The domain name for the Autonomous VM cluster.
     *
     * @cloudformationAttribute Domain
     */
    readonly attrDomain: string;
    /**
     * The minimum value to which you can scale down the Exadata storage, in TB.
     *
     * @cloudformationAttribute ExadataStorageInTBsLowestScaledValue
     */
    readonly attrExadataStorageInTBsLowestScaledValue: cdk.IResolvable;
    /**
     * The hostname for the Autonomous VM cluster.
     *
     * @cloudformationAttribute Hostname
     */
    readonly attrHostname: string;
    /**
     * The minimum value to which you can scale down the maximum number of Autonomous CDBs.
     *
     * @cloudformationAttribute MaxAcdsLowestScaledValue
     */
    readonly attrMaxAcdsLowestScaledValue: number;
    /**
     * The total amount of memory allocated to the Autonomous VM cluster, in gigabytes (GB).
     *
     * @cloudformationAttribute MemorySizeInGBs
     */
    readonly attrMemorySizeInGBs: number;
    /**
     * The number of database server nodes in the Autonomous VM cluster.
     *
     * @cloudformationAttribute NodeCount
     */
    readonly attrNodeCount: number;
    /**
     * The number of Autonomous CDBs that can't be provisioned because of resource constraints.
     *
     * @cloudformationAttribute NonProvisionableAutonomousContainerDatabases
     */
    readonly attrNonProvisionableAutonomousContainerDatabases: number;
    /**
     * The Oracle Cloud Identifier (OCID) of the Autonomous VM cluster.
     *
     * @cloudformationAttribute Ocid
     */
    readonly attrOcid: string;
    /**
     * The name of the OCI resource anchor associated with this Autonomous VM cluster.
     *
     * @cloudformationAttribute OciResourceAnchorName
     */
    readonly attrOciResourceAnchorName: string;
    /**
     * The URL for accessing the OCI console page for this Autonomous VM cluster.
     *
     * @cloudformationAttribute OciUrl
     */
    readonly attrOciUrl: string;
    /**
     * The number of Autonomous CDBs that can be provisioned in the Autonomous VM cluster.
     *
     * @cloudformationAttribute ProvisionableAutonomousContainerDatabases
     */
    readonly attrProvisionableAutonomousContainerDatabases: number;
    /**
     * The number of Autonomous CDBs currently provisioned in the Autonomous VM cluster.
     *
     * @cloudformationAttribute ProvisionedAutonomousContainerDatabases
     */
    readonly attrProvisionedAutonomousContainerDatabases: number;
    /**
     * The number of CPU cores currently provisioned in the Autonomous VM cluster.
     *
     * @cloudformationAttribute ProvisionedCpus
     */
    readonly attrProvisionedCpus: cdk.IResolvable;
    /**
     * The number of CPU cores that can be reclaimed from terminated or scaled-down Autonomous Databases.
     *
     * @cloudformationAttribute ReclaimableCpus
     */
    readonly attrReclaimableCpus: cdk.IResolvable;
    /**
     * The number of CPU cores reserved for system operations and redundancy.
     *
     * @cloudformationAttribute ReservedCpus
     */
    readonly attrReservedCpus: cdk.IResolvable;
    /**
     * The shape of the Exadata infrastructure for the Autonomous VM cluster.
     *
     * @cloudformationAttribute Shape
     */
    readonly attrShape: string;
    /**
     * The data storage size allocated for Autonomous Databases in the Autonomous VM cluster, in TB.
     */
    autonomousDataStorageSizeInTBs?: number;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly cdkTagManager: cdk.TagManager;
    /**
     * The unique identifier of the Cloud Exadata Infrastructure containing this Autonomous VM cluster.
     */
    cloudExadataInfrastructureId?: string;
    /**
     * The number of CPU cores enabled per node in the Autonomous VM cluster.
     */
    cpuCoreCountPerNode?: number;
    /**
     * The list of database servers associated with the Autonomous VM cluster.
     */
    dbServers?: Array<string>;
    /**
     * The user-provided description of the Autonomous VM cluster.
     */
    description?: string;
    /**
     * The display name of the Autonomous VM cluster.
     */
    displayName?: string;
    /**
     * Specifies whether mutual TLS (mTLS) authentication is enabled for the Autonomous VM cluster.
     */
    isMtlsEnabledVmCluster?: boolean | cdk.IResolvable;
    /**
     * The Oracle license model that applies to the Autonomous VM cluster.
     */
    licenseModel?: string;
    /**
     * The scheduling details for the maintenance window.
     */
    maintenanceWindow?: cdk.IResolvable | CfnCloudAutonomousVmCluster.MaintenanceWindowProperty;
    /**
     * The amount of memory allocated per Oracle Compute Unit, in GB.
     */
    memoryPerOracleComputeUnitInGBs?: number;
    /**
     * The unique identifier of the ODB network associated with this Autonomous VM cluster.
     */
    odbNetworkId?: string;
    /**
     * The SCAN listener port for non-TLS (TCP) protocol.
     */
    scanListenerPortNonTls?: number;
    /**
     * The SCAN listener port for TLS (TCP) protocol.
     */
    scanListenerPortTls?: number;
    /**
     * Tags to assign to the Autonomous Vm Cluster.
     */
    tags?: Array<cdk.CfnTag>;
    /**
     * The time zone of the Autonomous VM cluster.
     */
    timeZone?: string;
    /**
     * The total number of Autonomous Container Databases that can be created with the allocated local storage.
     */
    totalContainerDatabases?: number;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props?: CfnCloudAutonomousVmClusterProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnCloudAutonomousVmCluster {
    /**
     * The scheduling details for the maintenance window.
     *
     * Patching and system updates take place during the maintenance window.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudautonomousvmcluster-maintenancewindow.html
     */
    interface MaintenanceWindowProperty {
        /**
         * The days of the week when maintenance can be performed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudautonomousvmcluster-maintenancewindow.html#cfn-odb-cloudautonomousvmcluster-maintenancewindow-daysofweek
         */
        readonly daysOfWeek?: Array<string>;
        /**
         * The hours of the day when maintenance can be performed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudautonomousvmcluster-maintenancewindow.html#cfn-odb-cloudautonomousvmcluster-maintenancewindow-hoursofday
         */
        readonly hoursOfDay?: Array<number> | cdk.IResolvable;
        /**
         * The lead time in weeks before the maintenance window.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudautonomousvmcluster-maintenancewindow.html#cfn-odb-cloudautonomousvmcluster-maintenancewindow-leadtimeinweeks
         */
        readonly leadTimeInWeeks?: number;
        /**
         * The months when maintenance can be performed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudautonomousvmcluster-maintenancewindow.html#cfn-odb-cloudautonomousvmcluster-maintenancewindow-months
         */
        readonly months?: Array<string>;
        /**
         * The preference for the maintenance window scheduling.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudautonomousvmcluster-maintenancewindow.html#cfn-odb-cloudautonomousvmcluster-maintenancewindow-preference
         */
        readonly preference?: string;
        /**
         * The weeks of the month when maintenance can be performed.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudautonomousvmcluster-maintenancewindow.html#cfn-odb-cloudautonomousvmcluster-maintenancewindow-weeksofmonth
         */
        readonly weeksOfMonth?: Array<number> | cdk.IResolvable;
    }
}
/**
 * Properties for defining a `CfnCloudAutonomousVmCluster`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html
 */
export interface CfnCloudAutonomousVmClusterProps {
    /**
     * The data storage size allocated for Autonomous Databases in the Autonomous VM cluster, in TB.
     *
     * Required when creating an Autonomous VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-autonomousdatastoragesizeintbs
     */
    readonly autonomousDataStorageSizeInTBs?: number;
    /**
     * The unique identifier of the Cloud Exadata Infrastructure containing this Autonomous VM cluster.
     *
     * Required when creating an Autonomous VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-cloudexadatainfrastructureid
     */
    readonly cloudExadataInfrastructureId?: string;
    /**
     * The number of CPU cores enabled per node in the Autonomous VM cluster.
     *
     * Required when creating an Autonomous VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-cpucorecountpernode
     */
    readonly cpuCoreCountPerNode?: number;
    /**
     * The list of database servers associated with the Autonomous VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-dbservers
     */
    readonly dbServers?: Array<string>;
    /**
     * The user-provided description of the Autonomous VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-description
     */
    readonly description?: string;
    /**
     * The display name of the Autonomous VM cluster.
     *
     * Required when creating an Autonomous VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-displayname
     */
    readonly displayName?: string;
    /**
     * Specifies whether mutual TLS (mTLS) authentication is enabled for the Autonomous VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-ismtlsenabledvmcluster
     */
    readonly isMtlsEnabledVmCluster?: boolean | cdk.IResolvable;
    /**
     * The Oracle license model that applies to the Autonomous VM cluster.
     *
     * Valid values are `LICENSE_INCLUDED` or `BRING_YOUR_OWN_LICENSE` .
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-licensemodel
     */
    readonly licenseModel?: string;
    /**
     * The scheduling details for the maintenance window.
     *
     * Patching and system updates take place during the maintenance window.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-maintenancewindow
     */
    readonly maintenanceWindow?: cdk.IResolvable | CfnCloudAutonomousVmCluster.MaintenanceWindowProperty;
    /**
     * The amount of memory allocated per Oracle Compute Unit, in GB.
     *
     * Required when creating an Autonomous VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-memoryperoraclecomputeunitingbs
     */
    readonly memoryPerOracleComputeUnitInGBs?: number;
    /**
     * The unique identifier of the ODB network associated with this Autonomous VM cluster.
     *
     * Required when creating an Autonomous VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-odbnetworkid
     */
    readonly odbNetworkId?: string;
    /**
     * The SCAN listener port for non-TLS (TCP) protocol.
     *
     * The default is 1521.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-scanlistenerportnontls
     */
    readonly scanListenerPortNonTls?: number;
    /**
     * The SCAN listener port for TLS (TCP) protocol.
     *
     * The default is 2484.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-scanlistenerporttls
     */
    readonly scanListenerPortTls?: number;
    /**
     * Tags to assign to the Autonomous Vm Cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
    /**
     * The time zone of the Autonomous VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-timezone
     */
    readonly timeZone?: string;
    /**
     * The total number of Autonomous Container Databases that can be created with the allocated local storage.
     *
     * Required when creating an Autonomous VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudautonomousvmcluster.html#cfn-odb-cloudautonomousvmcluster-totalcontainerdatabases
     */
    readonly totalContainerDatabases?: number;
}
/**
 * The `AWS::ODB::CloudExadataInfrastructure` resource creates an Exadata infrastructure.
 *
 * An Exadata infrastructure provides the underlying compute and storage resources for Oracle Database workloads.
 *
 * @cloudformationResource AWS::ODB::CloudExadataInfrastructure
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudexadatainfrastructure.html
 */
export declare class CfnCloudExadataInfrastructure extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggableV2 {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnCloudExadataInfrastructure from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnCloudExadataInfrastructure;
    /**
     * The number of storage servers requested for the Exadata infrastructure.
     *
     * @cloudformationAttribute ActivatedStorageCount
     */
    readonly attrActivatedStorageCount: number;
    /**
     * The number of storage servers requested for the Exadata infrastructure.
     *
     * @cloudformationAttribute AdditionalStorageCount
     */
    readonly attrAdditionalStorageCount: number;
    /**
     * The amount of available storage, in gigabytes (GB), for the Exadata infrastructure.
     *
     * @cloudformationAttribute AvailableStorageSizeInGBs
     */
    readonly attrAvailableStorageSizeInGBs: number;
    /**
     * The Amazon Resource Name (ARN) for the Exadata infrastructure.
     *
     * @cloudformationAttribute CloudExadataInfrastructureArn
     */
    readonly attrCloudExadataInfrastructureArn: string;
    /**
     * The unique identifier for the Exadata infrastructure.
     *
     * @cloudformationAttribute CloudExadataInfrastructureId
     */
    readonly attrCloudExadataInfrastructureId: string;
    /**
     * The OCI model compute model used when you create or clone an instance: ECPU or OCPU. An ECPU is an abstracted measure of compute resources. ECPUs are based on the number of cores elastically allocated from a pool of compute and storage servers. An OCPU is a legacy physical measure of compute resources. OCPUs are based on the physical core of a processor with hyper-threading enabled.
     *
     * @cloudformationAttribute ComputeModel
     */
    readonly attrComputeModel: string;
    /**
     * The total number of CPU cores that are allocated to the Exadata infrastructure.
     *
     * @cloudformationAttribute CpuCount
     */
    readonly attrCpuCount: number;
    /**
     * The size of the Exadata infrastructure's data disk group, in terabytes (TB).
     *
     * @cloudformationAttribute DataStorageSizeInTBs
     */
    readonly attrDataStorageSizeInTBs: cdk.IResolvable;
    /**
     * The size of the Exadata infrastructure's local node storage, in gigabytes (GB).
     *
     * @cloudformationAttribute DbNodeStorageSizeInGBs
     */
    readonly attrDbNodeStorageSizeInGBs: number;
    /**
     * The list of database server identifiers for the Exadata infrastructure.
     *
     * @cloudformationAttribute DbServerIds
     */
    readonly attrDbServerIds: Array<string>;
    /**
     * The software version of the database servers (dom0) in the Exadata infrastructure.
     *
     * @cloudformationAttribute DbServerVersion
     */
    readonly attrDbServerVersion: string;
    /**
     * The total number of CPU cores available on the Exadata infrastructure.
     *
     * @cloudformationAttribute MaxCpuCount
     */
    readonly attrMaxCpuCount: number;
    /**
     * The total amount of data disk group storage, in terabytes (TB), that's available on the Exadata infrastructure.
     *
     * @cloudformationAttribute MaxDataStorageInTBs
     */
    readonly attrMaxDataStorageInTBs: cdk.IResolvable;
    /**
     * The total amount of local node storage, in gigabytes (GB), that's available on the Exadata infrastructure.
     *
     * @cloudformationAttribute MaxDbNodeStorageSizeInGBs
     */
    readonly attrMaxDbNodeStorageSizeInGBs: number;
    /**
     * The total amount of memory, in gigabytes (GB), that's available on the Exadata infrastructure.
     *
     * @cloudformationAttribute MaxMemoryInGBs
     */
    readonly attrMaxMemoryInGBs: number;
    /**
     * The amount of memory, in gigabytes (GB), that's allocated on the Exadata infrastructure.
     *
     * @cloudformationAttribute MemorySizeInGBs
     */
    readonly attrMemorySizeInGBs: number;
    /**
     * The OCID of the Exadata infrastructure.
     *
     * @cloudformationAttribute Ocid
     */
    readonly attrOcid: string;
    /**
     * The name of the OCI resource anchor for the Exadata infrastructure.
     *
     * @cloudformationAttribute OciResourceAnchorName
     */
    readonly attrOciResourceAnchorName: string;
    /**
     * The HTTPS link to the Exadata infrastructure in OCI.
     *
     * @cloudformationAttribute OciUrl
     */
    readonly attrOciUrl: string;
    /**
     * The software version of the storage servers on the Exadata infrastructure.
     *
     * @cloudformationAttribute StorageServerVersion
     */
    readonly attrStorageServerVersion: string;
    /**
     * The total amount of storage, in gigabytes (GB), on the the Exadata infrastructure.
     *
     * @cloudformationAttribute TotalStorageSizeInGBs
     */
    readonly attrTotalStorageSizeInGBs: number;
    /**
     * The name of the Availability Zone (AZ) where the Exadata infrastructure is located.
     */
    availabilityZone?: string;
    /**
     * The AZ ID of the AZ where the Exadata infrastructure is located.
     */
    availabilityZoneId?: string;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly cdkTagManager: cdk.TagManager;
    /**
     * The number of database servers for the Exadata infrastructure.
     */
    computeCount?: number;
    /**
     * The email addresses of contacts to receive notification from Oracle about maintenance updates for the Exadata infrastructure.
     */
    customerContactsToSendToOci?: Array<CfnCloudExadataInfrastructure.CustomerContactProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * The database server model type of the Exadata infrastructure.
     */
    databaseServerType?: string;
    /**
     * The user-friendly name for the Exadata infrastructure.
     */
    displayName?: string;
    /**
     * The model name of the Exadata infrastructure.
     */
    shape?: string;
    /**
     * The number of storage servers that are activated for the Exadata infrastructure.
     */
    storageCount?: number;
    /**
     * The storage server model type of the Exadata infrastructure.
     */
    storageServerType?: string;
    /**
     * Tags to assign to the Exadata Infrastructure.
     */
    tags?: Array<cdk.CfnTag>;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props?: CfnCloudExadataInfrastructureProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnCloudExadataInfrastructure {
    /**
     * A contact to receive notification from Oracle about maintenance updates for a specific Exadata infrastructure.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudexadatainfrastructure-customercontact.html
     */
    interface CustomerContactProperty {
        /**
         * The email address of the contact.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudexadatainfrastructure-customercontact.html#cfn-odb-cloudexadatainfrastructure-customercontact-email
         */
        readonly email?: string;
    }
}
/**
 * Properties for defining a `CfnCloudExadataInfrastructure`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudexadatainfrastructure.html
 */
export interface CfnCloudExadataInfrastructureProps {
    /**
     * The name of the Availability Zone (AZ) where the Exadata infrastructure is located.
     *
     * Required when creating an Exadata infrastructure. Specify either AvailabilityZone or AvailabilityZoneId to define the location of the infrastructure.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudexadatainfrastructure.html#cfn-odb-cloudexadatainfrastructure-availabilityzone
     */
    readonly availabilityZone?: string;
    /**
     * The AZ ID of the AZ where the Exadata infrastructure is located.
     *
     * Required when creating an Exadata infrastructure. Specify either AvailabilityZone or AvailabilityZoneId to define the location of the infrastructure.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudexadatainfrastructure.html#cfn-odb-cloudexadatainfrastructure-availabilityzoneid
     */
    readonly availabilityZoneId?: string;
    /**
     * The number of database servers for the Exadata infrastructure.
     *
     * Required when creating an Exadata infrastructure.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudexadatainfrastructure.html#cfn-odb-cloudexadatainfrastructure-computecount
     */
    readonly computeCount?: number;
    /**
     * The email addresses of contacts to receive notification from Oracle about maintenance updates for the Exadata infrastructure.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudexadatainfrastructure.html#cfn-odb-cloudexadatainfrastructure-customercontactstosendtooci
     */
    readonly customerContactsToSendToOci?: Array<CfnCloudExadataInfrastructure.CustomerContactProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * The database server model type of the Exadata infrastructure.
     *
     * For the list of valid model names, use the `ListDbSystemShapes` operation.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudexadatainfrastructure.html#cfn-odb-cloudexadatainfrastructure-databaseservertype
     */
    readonly databaseServerType?: string;
    /**
     * The user-friendly name for the Exadata infrastructure.
     *
     * Required when creating an Exadata infrastructure.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudexadatainfrastructure.html#cfn-odb-cloudexadatainfrastructure-displayname
     */
    readonly displayName?: string;
    /**
     * The model name of the Exadata infrastructure.
     *
     * Required when creating an Exadata infrastructure.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudexadatainfrastructure.html#cfn-odb-cloudexadatainfrastructure-shape
     */
    readonly shape?: string;
    /**
     * The number of storage servers that are activated for the Exadata infrastructure.
     *
     * Required when creating an Exadata infrastructure.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudexadatainfrastructure.html#cfn-odb-cloudexadatainfrastructure-storagecount
     */
    readonly storageCount?: number;
    /**
     * The storage server model type of the Exadata infrastructure.
     *
     * For the list of valid model names, use the `ListDbSystemShapes` operation.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudexadatainfrastructure.html#cfn-odb-cloudexadatainfrastructure-storageservertype
     */
    readonly storageServerType?: string;
    /**
     * Tags to assign to the Exadata Infrastructure.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudexadatainfrastructure.html#cfn-odb-cloudexadatainfrastructure-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
}
/**
 * The `AWS::ODB::CloudVmCluster` resource creates a VM cluster on the specified Exadata infrastructure in the Oracle Database.
 *
 * A VM cluster provides the compute resources for Oracle Database workloads.
 *
 * @cloudformationResource AWS::ODB::CloudVmCluster
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html
 */
export declare class CfnCloudVmCluster extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggableV2 {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnCloudVmCluster from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnCloudVmCluster;
    /**
     * The Amazon Resource Name (ARN) of the VM cluster.
     *
     * @cloudformationAttribute CloudVmClusterArn
     */
    readonly attrCloudVmClusterArn: string;
    /**
     * The unique identifier of the VM cluster.
     *
     * @cloudformationAttribute CloudVmClusterId
     */
    readonly attrCloudVmClusterId: string;
    /**
     * The OCI model compute model used when you create or clone an instance: ECPU or OCPU. An ECPU is an abstracted measure of compute resources. ECPUs are based on the number of cores elastically allocated from a pool of compute and storage servers. An OCPU is a legacy physical measure of compute resources. OCPUs are based on the physical core of a processor with hyper-threading enabled.
     *
     * @cloudformationAttribute ComputeModel
     */
    readonly attrComputeModel: string;
    /**
     * The type of redundancy configured for the VM cluster. `NORMAL` is 2-way redundancy. `HIGH` is 3-way redundancy.
     *
     * @cloudformationAttribute DiskRedundancy
     */
    readonly attrDiskRedundancy: string;
    /**
     * The domain of the VM cluster.
     *
     * @cloudformationAttribute Domain
     */
    readonly attrDomain: string;
    /**
     * The port number configured for the listener on the VM cluster.
     *
     * @cloudformationAttribute ListenerPort
     */
    readonly attrListenerPort: number;
    /**
     * The number of nodes in the VM cluster.
     *
     * @cloudformationAttribute NodeCount
     */
    readonly attrNodeCount: number;
    /**
     * The OCID of the VM cluster.
     *
     * @cloudformationAttribute Ocid
     */
    readonly attrOcid: string;
    /**
     * The name of the OCI resource anchor for the VM cluster.
     *
     * @cloudformationAttribute OciResourceAnchorName
     */
    readonly attrOciResourceAnchorName: string;
    /**
     * The HTTPS link to the VM cluster in OCI.
     *
     * @cloudformationAttribute OciUrl
     */
    readonly attrOciUrl: string;
    /**
     * The FQDN of the DNS record for the Single Client Access Name (SCAN) IP addresses that are associated with the VM cluster.
     *
     * @cloudformationAttribute ScanDnsName
     */
    readonly attrScanDnsName: string;
    /**
     * The OCID of the SCAN IP addresses that are associated with the VM cluster.
     *
     * @cloudformationAttribute ScanIpIds
     */
    readonly attrScanIpIds: Array<string>;
    /**
     * The hardware model name of the Exadata infrastructure that's running the VM cluster.
     *
     * @cloudformationAttribute Shape
     */
    readonly attrShape: string;
    /**
     * The amount of local node storage, in gigabytes (GB), that's allocated to the VM cluster.
     *
     * @cloudformationAttribute StorageSizeInGBs
     */
    readonly attrStorageSizeInGBs: number;
    /**
     * The virtual IP (VIP) addresses that are associated with the VM cluster. Oracle's Cluster Ready Services (CRS) creates and maintains one VIP address for each node in the VM cluster to enable failover. If one node fails, the VIP is reassigned to another active node in the cluster.
     *
     * @cloudformationAttribute VipIds
     */
    readonly attrVipIds: Array<string>;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly cdkTagManager: cdk.TagManager;
    /**
     * The unique identifier of the Exadata infrastructure that this VM cluster belongs to.
     */
    cloudExadataInfrastructureId?: string;
    /**
     * The name of the Grid Infrastructure (GI) cluster.
     */
    clusterName?: string;
    /**
     * The number of CPU cores enabled on the VM cluster.
     */
    cpuCoreCount?: number;
    /**
     * The set of diagnostic collection options enabled for the VM cluster.
     */
    dataCollectionOptions?: CfnCloudVmCluster.DataCollectionOptionsProperty | cdk.IResolvable;
    /**
     * The size of the data disk group, in terabytes (TB), that's allocated for the VM cluster.
     */
    dataStorageSizeInTBs?: number;
    /**
     * The amount of local node storage, in gigabytes (GB), that's allocated for the VM cluster.
     */
    dbNodeStorageSizeInGBs?: number;
    /**
     * The list of database servers for the VM cluster.
     */
    dbServers?: Array<string>;
    /**
     * The user-friendly name for the VM cluster.
     */
    displayName?: string;
    /**
     * The software version of the Oracle Grid Infrastructure (GI) for the VM cluster.
     */
    giVersion?: string;
    /**
     * The host name for the VM cluster.
     */
    hostname?: string;
    /**
     * Specifies whether database backups to local Exadata storage are enabled for the VM cluster.
     */
    isLocalBackupEnabled?: boolean | cdk.IResolvable;
    /**
     * Specifies whether the VM cluster is configured with a sparse disk group.
     */
    isSparseDiskgroupEnabled?: boolean | cdk.IResolvable;
    /**
     * The Oracle license model applied to the VM cluster.
     */
    licenseModel?: string;
    /**
     * The amount of memory, in gigabytes (GB), that's allocated for the VM cluster.
     */
    memorySizeInGBs?: number;
    /**
     * The unique identifier of the ODB network for the VM cluster.
     */
    odbNetworkId?: string;
    /**
     * The port number for TCP connections to the single client access name (SCAN) listener.
     */
    scanListenerPortTcp?: number;
    /**
     * The public key portion of one or more key pairs used for SSH access to the VM cluster.
     */
    sshPublicKeys?: Array<string>;
    /**
     * The operating system version of the image chosen for the VM cluster.
     */
    systemVersion?: string;
    /**
     * Tags to assign to the Vm Cluster.
     */
    tags?: Array<cdk.CfnTag>;
    /**
     * The time zone of the VM cluster.
     */
    timeZone?: string;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props?: CfnCloudVmClusterProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnCloudVmCluster {
    /**
     * Information about the data collection options enabled for a VM cluster.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudvmcluster-datacollectionoptions.html
     */
    interface DataCollectionOptionsProperty {
        /**
         * Specifies whether diagnostic collection is enabled for the VM cluster.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudvmcluster-datacollectionoptions.html#cfn-odb-cloudvmcluster-datacollectionoptions-isdiagnosticseventsenabled
         */
        readonly isDiagnosticsEventsEnabled?: boolean | cdk.IResolvable;
        /**
         * Specifies whether health monitoring is enabled for the VM cluster.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudvmcluster-datacollectionoptions.html#cfn-odb-cloudvmcluster-datacollectionoptions-ishealthmonitoringenabled
         */
        readonly isHealthMonitoringEnabled?: boolean | cdk.IResolvable;
        /**
         * Specifies whether incident logs are enabled for the VM cluster.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-odb-cloudvmcluster-datacollectionoptions.html#cfn-odb-cloudvmcluster-datacollectionoptions-isincidentlogsenabled
         */
        readonly isIncidentLogsEnabled?: boolean | cdk.IResolvable;
    }
}
/**
 * Properties for defining a `CfnCloudVmCluster`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html
 */
export interface CfnCloudVmClusterProps {
    /**
     * The unique identifier of the Exadata infrastructure that this VM cluster belongs to.
     *
     * Required when creating a VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-cloudexadatainfrastructureid
     */
    readonly cloudExadataInfrastructureId?: string;
    /**
     * The name of the Grid Infrastructure (GI) cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-clustername
     */
    readonly clusterName?: string;
    /**
     * The number of CPU cores enabled on the VM cluster.
     *
     * Required when creating a VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-cpucorecount
     */
    readonly cpuCoreCount?: number;
    /**
     * The set of diagnostic collection options enabled for the VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-datacollectionoptions
     */
    readonly dataCollectionOptions?: CfnCloudVmCluster.DataCollectionOptionsProperty | cdk.IResolvable;
    /**
     * The size of the data disk group, in terabytes (TB), that's allocated for the VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-datastoragesizeintbs
     */
    readonly dataStorageSizeInTBs?: number;
    /**
     * The amount of local node storage, in gigabytes (GB), that's allocated for the VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-dbnodestoragesizeingbs
     */
    readonly dbNodeStorageSizeInGBs?: number;
    /**
     * The list of database servers for the VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-dbservers
     */
    readonly dbServers?: Array<string>;
    /**
     * The user-friendly name for the VM cluster.
     *
     * Required when creating a VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-displayname
     */
    readonly displayName?: string;
    /**
     * The software version of the Oracle Grid Infrastructure (GI) for the VM cluster.
     *
     * Required when creating a VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-giversion
     */
    readonly giVersion?: string;
    /**
     * The host name for the VM cluster.
     *
     * Required when creating a VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-hostname
     */
    readonly hostname?: string;
    /**
     * Specifies whether database backups to local Exadata storage are enabled for the VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-islocalbackupenabled
     */
    readonly isLocalBackupEnabled?: boolean | cdk.IResolvable;
    /**
     * Specifies whether the VM cluster is configured with a sparse disk group.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-issparsediskgroupenabled
     */
    readonly isSparseDiskgroupEnabled?: boolean | cdk.IResolvable;
    /**
     * The Oracle license model applied to the VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-licensemodel
     */
    readonly licenseModel?: string;
    /**
     * The amount of memory, in gigabytes (GB), that's allocated for the VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-memorysizeingbs
     */
    readonly memorySizeInGBs?: number;
    /**
     * The unique identifier of the ODB network for the VM cluster.
     *
     * Required when creating a VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-odbnetworkid
     */
    readonly odbNetworkId?: string;
    /**
     * The port number for TCP connections to the single client access name (SCAN) listener.
     *
     * Valid values: `1024–8999` with the following exceptions: `2484` , `6100` , `6200` , `7060` , `7070` , `7085` , and `7879`
     *
     * Default: `1521`
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-scanlistenerporttcp
     */
    readonly scanListenerPortTcp?: number;
    /**
     * The public key portion of one or more key pairs used for SSH access to the VM cluster.
     *
     * Required when creating a VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-sshpublickeys
     */
    readonly sshPublicKeys?: Array<string>;
    /**
     * The operating system version of the image chosen for the VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-systemversion
     */
    readonly systemVersion?: string;
    /**
     * Tags to assign to the Vm Cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
    /**
     * The time zone of the VM cluster.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-cloudvmcluster.html#cfn-odb-cloudvmcluster-timezone
     */
    readonly timeZone?: string;
}
/**
 * The `AWS::ODB::OdbNetwork` resource creates an ODB network.
 *
 * An ODB network provides the networking foundation for Oracle Database resources.
 *
 * @cloudformationResource AWS::ODB::OdbNetwork
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-odbnetwork.html
 */
export declare class CfnOdbNetwork extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggableV2 {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnOdbNetwork from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnOdbNetwork;
    /**
     * The unique identifier of the OCI network anchor for the ODB network.
     *
     * @cloudformationAttribute OciNetworkAnchorId
     */
    readonly attrOciNetworkAnchorId: string;
    /**
     * The name of the OCI resource anchor that's associated with the ODB network.
     *
     * @cloudformationAttribute OciResourceAnchorName
     */
    readonly attrOciResourceAnchorName: string;
    /**
     * The URL for the VCN that's associated with the ODB network.
     *
     * @cloudformationAttribute OciVcnUrl
     */
    readonly attrOciVcnUrl: string;
    /**
     * The Amazon Resource Name (ARN) of the ODB network.
     *
     * @cloudformationAttribute OdbNetworkArn
     */
    readonly attrOdbNetworkArn: string;
    /**
     * The unique identifier of the ODB network.
     *
     * @cloudformationAttribute OdbNetworkId
     */
    readonly attrOdbNetworkId: string;
    /**
     * The Availability Zone (AZ) where the ODB network is located.
     */
    availabilityZone?: string;
    /**
     * The AZ ID of the AZ where the ODB network is located.
     */
    availabilityZoneId?: string;
    /**
     * The CIDR range of the backup subnet in the ODB network.
     */
    backupSubnetCidr?: string;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly cdkTagManager: cdk.TagManager;
    /**
     * The CIDR range of the client subnet in the ODB network.
     */
    clientSubnetCidr?: string;
    /**
     * The DNS prefix to the default DNS domain name.
     */
    defaultDnsPrefix?: string;
    /**
     * Specifies whether to delete associated OCI networking resources along with the ODB network.
     */
    deleteAssociatedResources?: boolean | cdk.IResolvable;
    /**
     * The user-friendly name of the ODB network.
     */
    displayName?: string;
    /**
     * Tags to assign to the Odb Network.
     */
    tags?: Array<cdk.CfnTag>;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props?: CfnOdbNetworkProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
/**
 * Properties for defining a `CfnOdbNetwork`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-odbnetwork.html
 */
export interface CfnOdbNetworkProps {
    /**
     * The Availability Zone (AZ) where the ODB network is located.
     *
     * Required when creating an ODB network. Specify either AvailabilityZone or AvailabilityZoneId to define the location of the network.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-odbnetwork.html#cfn-odb-odbnetwork-availabilityzone
     */
    readonly availabilityZone?: string;
    /**
     * The AZ ID of the AZ where the ODB network is located.
     *
     * Required when creating an ODB network. Specify either AvailabilityZone or AvailabilityZoneId to define the location of the network.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-odbnetwork.html#cfn-odb-odbnetwork-availabilityzoneid
     */
    readonly availabilityZoneId?: string;
    /**
     * The CIDR range of the backup subnet in the ODB network.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-odbnetwork.html#cfn-odb-odbnetwork-backupsubnetcidr
     */
    readonly backupSubnetCidr?: string;
    /**
     * The CIDR range of the client subnet in the ODB network.
     *
     * Required when creating an ODB network.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-odbnetwork.html#cfn-odb-odbnetwork-clientsubnetcidr
     */
    readonly clientSubnetCidr?: string;
    /**
     * The DNS prefix to the default DNS domain name.
     *
     * The default DNS domain name is oraclevcn.com.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-odbnetwork.html#cfn-odb-odbnetwork-defaultdnsprefix
     */
    readonly defaultDnsPrefix?: string;
    /**
     * Specifies whether to delete associated OCI networking resources along with the ODB network.
     *
     * Required when creating an ODB network.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-odbnetwork.html#cfn-odb-odbnetwork-deleteassociatedresources
     */
    readonly deleteAssociatedResources?: boolean | cdk.IResolvable;
    /**
     * The user-friendly name of the ODB network.
     *
     * Required when creating an ODB network.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-odbnetwork.html#cfn-odb-odbnetwork-displayname
     */
    readonly displayName?: string;
    /**
     * Tags to assign to the Odb Network.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-odb-odbnetwork.html#cfn-odb-odbnetwork-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
}
